Dimension
---------

.. todo:: Fill overview page

.. autosummary::
    :toctree: _generated/dimension

    zfit.dimension.Space
    zfit.dimension.combine_spaces
    zfit.dimension.add_spaces
    zfit.dimension.Coordinates
